<?php

add_filter( 'saturn_tables_menus', 'saturn_tables_menus_countries', 10, 1 );

function saturn_tables_menus_countries( $saturn_tables_menus ) {
	
	$saturn_tables_menus[] = array (
					'type' => 'list_table',
					'page_title' => __( 'Countries' ),
					'menu_title' => __( 'Countries' ),
					'capability' => 'edit_posts',
					'menu_slug' => 'saturn-tables-countries-table',
					'callable' => 'saturn_tables_countries_list_table_func',
					'icon_url' => '',
					'position' => '40'
			);	
	
	$saturn_tables_menus[] = array(
					'type' => 'input_form',
					'parent_slug' => 'saturn-tables-countries-table',
					'page_title' => __( 'Add Country' ),
					'menu_title' => __( 'Add Country' ),
					'capability' => 'edit_posts',
					'menu_slug' => 'saturn-tables-add-edit-country',
					'callable' => 'saturn_tables_add_edit_country_func');
	
	$saturn_tables_menus[] = array(
					'type' => 'list_table',
					'parent_slug' => 'saturn-tables-countries-table',
					'page_title' => __( 'Cities' ),
					'menu_title' => __( 'Cities' ),
					'capability' => 'edit_posts',
					'menu_slug' => 'saturn-tables-cities-table',
					'callable' => 'saturn_tables_cities_list_table_func');

	$saturn_tables_menus[] = array(
					'type' => 'input_form',
					'parent_slug' => '',
					'page_title' => __( 'Add Cities' ),
					'menu_title' => __( 'Add Cities' ),
					'capability' => 'edit_posts',
					'menu_slug' => 'saturn-tables-add-edit-city',
					'callable' => 'saturn_tables_add_edit_city_func');

	
	$saturn_tables_menus[] = array(
					'type' => 'submenu',
					'parent_slug' => 'saturn-tables-countries-table',
					'page_title' => __( 'Countries Import' ),
					'menu_title' => __( 'Countries Import' ),
					'capability' => 'edit_posts',
					'menu_slug' => 'saturn-tables-world-import-export',
					'callable' => 'saturn_tables_cities_countries_import_func');
	
	
	return $saturn_tables_menus;

}

/**************************************/
/* COUNTRIES LIST TABLE MENU CALLBACK */
/**************************************/

function saturn_tables_countries_list_table_func($page = "", $item = array(), $page_number = 1) {
		
			/* STANDARD LIST TABLE DEFINITION VALUES */
			
			$table = new Saturn_Tables_Countries_List_Table();
			
			//you can write code in here, probably best to write as little as possible
			$add_new_link =  admin_url("/admin.php/?page=saturn-tables-add-edit-country&id=0");			
			$list_table_definitions['menu_title'] = '<h1 class="wp-heading-inline">View Countries</h1><a href="' . $add_new_link . '" class="page-title-action">Add New</a>';
	
			$list_table_definitions['header'] = '<p>The World database is a list of cities and countries.</p>';
			
			$list_table_definitions['columns'] = array('country' => "Country", 'iso2' => "iso2", 'iso3' => "iso3", 'region' => "Region", 'population' => "Population", 'area' => "Area", 'density' => "Density", 'gdp' => "GDP", 'literacy' => "Literacy");
			
			$list_table_definitions['get_data'] = array($table, 'return_items');
			
			$list_table_definitions['get_data_count'] = array($table, 'return_items_count');
			
			/* LIST TABLE ACTION DEFINITION VALUES */
			
			$list_table_definitions['column_markup'] = call_user_func(array($table, 'list_table_markup'), $page, $item, $page_number);
						
			$list_table_definitions['link_actions'] = call_user_func(array($table, 'list_table_actions'), $page, $item, $page_number);
			
			$list_table_definitions['process_link_actions'] = array($table, 'process_link_actions');
											
			$list_table_definitions['footer'] = '<p>Powered by <a href="https://saturntables.com/" target="_blank">Saturn Tables</a></p>';
			
	return $list_table_definitions;
	
}

/****************************************************/
/* END COUNTIES LIST TABLE DEFINITION MENU CALLBACK */
/****************************************************/

/***********************************************/
/* COUNTRIES LIST TABLE CALLABLE FUNCTIONS */
/***********************************************/

class Saturn_Tables_Countries_List_Table {

	function return_items ($per_page, $page_number) {
		
		global $wpdb;
		
		$offset = ($per_page * ($page_number -1));
		
		$query = "SELECT id, iso2, iso3, country, region, population, area, density, gdp, literacy FROM saturn_tables_countries ORDER BY country LIMIT $per_page OFFSET $offset";
		if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'")) { 
			$items = $wpdb->get_results($query, ARRAY_A);
			return $items;
		}	
	}
	

	function return_items_count() {
		
		global $wpdb;	
			
		$query = "SELECT count(id) FROM saturn_tables_countries";
		
		if  ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'")) {
			return $wpdb->get_var($query);
		}
		
	}


	function list_table_markup($page, $item, $page_number) {
		
		$item_id = (isset($item['id']) && ((int)$item['id'] > 0)) ? $item['id'] : 0;
		$country = (isset($item['country'])) ? $item['country'] : "";
	
		return array('country' => sprintf('<strong><a href="?page=%s&id=%d">%s</a></strong>', 'saturn-tables-add-edit-country', $item_id,  $country ) );
	
	}

	function list_table_actions ( $page, $item, $page_number) {
		
		$item_id = (isset($item['id']) && ((int)$item['id'] > 0)) ? $item['id'] : 0;
		$country = (isset($item['country'])) ? $item['country'] : "";
				
		$links = array( 'country' => array('delete' => sprintf( "<a href=\"?page=%s&delete_id=%d&paged=%d\" onclick=\" return confirm('Are yuu sure you want to delete " . $country . " and all its cities?');\">Delete Permanently</a>", $page, $item_id, $page_number ),
										   'edit' => sprintf( '<a href="?page=%s&id=%d">Edit</a>', 'saturn-tables-add-edit-country', $item_id ),
										   'view' => sprintf( '<a href="?page=%s&country_id=%d">View Cities</a>', 'saturn-tables-cities-table', $item_id ),
										   'add' => sprintf( '<a href="?page=%s&country_id=%d">Add City</a>', 'saturn-tables-add-edit-city', $item_id ) ) );
	
	
		return $links;
	}


	function process_link_actions() {
		
		global $wpdb;
			
		if ( (isset($_GET['delete_id']) &&  $delete_id = (int)$_GET['delete_id']) > 0) {
			
			$wpdb->delete( 'saturn_tables_countries', array('id' => $delete_id),  array('id' => '%d'));
			$wpdb->delete( 'saturn_tables_cities', array('country_id' => $delete_id),  array('country_id' => '%d'));
			
			//redirect without delete_id
			parse_str($_SERVER['QUERY_STRING'], $query_string);
			unset($query_string['delete_id']);
			$redirect = admin_url("admin.php") . "?" . http_build_query($query_string);
			wp_redirect( $redirect );		
			exit;
		}
		
	}

}

/***********************************************/
/* END COUNTRIES LIST TABLE CALLABLE FUNCTIONS */
/***********************************************/

/************************************************/
/* COUNTRIES INPUT FORM DEFINITION MENU CALLBACK */
/************************************************/

function saturn_tables_add_edit_country_func() {
	
	$form = new My_Countries_Input_Form();
	
	$id = isset($_GET['id']) ? $_GET['id'] : 0;
	$input_form_definitions['menu_title'] = $id > 0 ? '<h1  class="wp-heading-inline">Edit Country</h1> <strong>[ID:' . $id . ']</strong>' : '<h1>Add Country</h1>';
	$input_form_definitions['header'] = $id > 0 ? '<p>Edit country below with this form.</p>' : '<p>Input new country with this form.</p>';	
	$input_form_definitions['form_definition'] = array($form, 'input_form_definition');
	$input_form_definitions['run_query'] = array($form, 'run_query');
	$input_form_definitions['process_post_vars'] = array($form, 'process_post_vars');
	$input_form_definitions['footer'] = '<p>Powered by <a href="https://saturntables.com/" target="_blank">Saturn Tables</a></p>';	
	
	return $input_form_definitions;
}

/****************************************************/
/* END COUNTRIES INPUT FORM DEFINITION MENU CALLBACK */
/****************************************************/


/*******************************************/
/* COUNTRIES INPUT FORM CALLABLE FUNCTIONS */
/*******************************************/

class My_Countries_Input_Form {

	function input_form_definition() {
		
		global $wpdb;
		
		if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'")) {
			$regions = $wpdb->get_col( "SELECT DISTINCT region FROM saturn_tables_countries ORDER BY country" );
		}
		
		$input_form['country'] = array ('label'=> "Country",  'type' => "text", "required" => "");
		$input_form['iso2'] = array('label'=> "iso2",  'type'=>"text", "required" => "" );
		$input_form['iso3'] = array( 'label'=> "iso3", 'type'=>"text",  "required" => "");
		$input_form['region'] = array ('label'=> "Region", 'type' => "select", 'options' => $regions, "required" => "" , 'usekey' => false);	
		$input_form['population'] = array ('label'=> "Population", 'type' => "number", 'step'=>"1", "required" => "");
		$input_form['area'] = array ('label'=> "Area", 'type' => "number", 'step'=>"1", "required" => "");	
		$input_form['density'] = array ('label'=> "Density", 'type' => "number", 'step'=>".1", "required" => "");
		$input_form['gdp'] = array ('label'=> "GDP", 'type' => "number", 'step'=>"1", "required" => "");
		$input_form['literacy'] = array ('label'=> "Literacy", 'type' => "number", 'step'=>".1", "required" => "");
		
		return $input_form;
		
	}
	
	
	function run_query($input_form, $query_return) {
		
		 
		global $wpdb;
		
		if (isset($_POST['submit'])) {
			
			foreach ($input_form as $key => $value) {
				if (isset($_POST[$key]))
					$post_vars[$key] = sanitize_text_field($_POST[$key]);
			}
		
			$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
			
			if ($id == 0) {
				
				 $data = array('country' => $post_vars['country'], 'iso2' => $post_vars['iso2'], 'iso3' => $post_vars['iso3'], 'region' => $post_vars['region'],
							   'population' => $post_vars['population'], 'area' => $post_vars['area'], 'density' => $post_vars['density'], 'gdp' => $post_vars['gdp'], 'literacy' => $post_vars['literacy']);
				 $formats = array('%s','%s','%s','%s','%d','%d','%f','%d','%f');
				 if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'")) {
					$query_return = $wpdb->insert('saturn_tables_countries', $data, $formats);
					return false;
				 }
				 
				 
			} elseif ($id > 0) {
				
				$data = array('country' => $post_vars['country'], 'iso2' => $post_vars['iso2'], 'iso3' => $post_vars['iso3'], 'region' => $post_vars['region'],
							   'population' => $post_vars['population'], 'area' => $post_vars['area'], 'density' => $post_vars['density'], 'gdp' => $post_vars['gdp'], 'literacy' => $post_vars['literacy']);
				$data_formats =  array('%s','%s','%s','%s','%d','%d','%f','%d','%f');;
				$where = array('id' => $id);
				$where_formats = array('%d');
				if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'")) {
					$query_return = $wpdb->update('saturn_tables_countries', $data, $where, $data_formats, $where_formats );			
					return false;
				}
			}
		}
	}
	
	
	function process_post_vars($input_form, $query_return, $post_vars) {
		
		global $wpdb;
		
		$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
		
		if (!$id && !$query_return) {		
			 $post_vars = array();		 
		} elseif ($id) {
			if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'")) {
				$post_vars = $wpdb->get_row($wpdb->prepare("SELECT iso2, iso3, country, region, population, area, density, gdp, literacy FROM saturn_tables_countries WHERE id = %d", $id), ARRAY_A);
			}
		}
		
		return $post_vars;
	}

}

/***********************************************/
/* END COUNTRIES INPUT FORM CALLABLE FUNCTIONS */
/***********************************************/

/***********************************/
/* CITIES LIST TABLE MENU CALLBACK */
/***********************************/

function saturn_tables_cities_list_table_func($page = "", $item = array(), $page_number = 1) {
		
			/* STANDARD LIST TABLE DEFINITION VALUES */
			
			$table = new Saturn_Tables_Cities_List_Table();
			
			//you can write code in here, probably best to write as little as possible		
			$list_table_definitions['menu_title'] = '<h1>View Cities</h1>';
	
			$list_table_definitions['header'] = '<p>The Cities table is a list of cities in the World Database.</p>';
			
			$list_table_definitions['columns'] = array( 'city'=>"City",'latitiude'=>"Latitiude",'longitude'=>"Longitude",'country'=>"Country",'iso2'=>"iso2",'iso3'=>"iso3",'state'=>"State",'capital'=>"Capital", 'population'=>"Population");
			
			$list_table_definitions['get_data'] = array($table, 'return_items');
			
			$list_table_definitions['get_data_count'] = array($table, 'return_items_count');
			
			/* LIST TABLE ACTION DEFINITION VALUES */
			
			$list_table_definitions['column_markup'] = call_user_func( array($table, 'list_table_markup'), $page, $item, $page_number);
						
			$list_table_definitions['link_actions'] = call_user_func( array($table, 'list_table_actions'), $page, $item, $page_number);
			
			$list_table_definitions['process_link_actions'] = array($table, 'process_link_actions');
											
			$list_table_definitions['footer'] = '<p>Powered by <a href="https://saturntables.com/" target="_blank">Saturn Tables</a></p>';
			
	return $list_table_definitions;
	
}

/****************************************/
/* END CITIES LIST TABLE MENU CALLBACK */
/****************************************/

/****************************************/
/* CITIES LIST TABLE CALLABLE FUNCTIONS */
/****************************************/

class Saturn_Tables_Cities_List_Table {

	function return_items ($per_page, $page_number) {
		
		global $wpdb;
		
		if (isset($_GET['country_id']) && ((int)$_GET['country_id'] > 0)) {
			$where = "country_id = " . (int)$_GET['country_id'];
		} else {
			$where = "1";
		}
			
		$offset = ($per_page * ($page_number -1));
		
		$query = "SELECT id, country_id, city, latitiude, longitude, country, iso2, iso3, state, capital, population FROM saturn_tables_cities WHERE " . $where . " ORDER BY city LIMIT $per_page OFFSET $offset";
		if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_cities'")) { 
			$items = $wpdb->get_results($query, ARRAY_A);
			return $items;
		}	
	}
		
	
	function return_items_count() {
		
		global $wpdb;
		
		if (isset($_GET['country_id']) && ((int)$_GET['country_id'] > 0)) {
			$where = "country_id = " . (int)$_GET['country_id'];
		} else {
			$where = "1";
		}
	
			
		$query = "SELECT count(id) FROM saturn_tables_cities WHERE " . $where;
		
		if  ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_cities'")) {
			return $wpdb->get_var($query);
		}
		
	}
	
	
	function list_table_markup($page, $item, $page_number) {
		
		$item_id = (isset($item['id']) && ((int)$item['id'] > 0)) ? $item['id'] : 0;
		$city = (isset($item['city'])) ? $item['city'] : "";
	
		return array('city' => sprintf('<strong><a href="?page=%s&id=%d">%s</a></strong>', 'saturn-tables-add-edit-city', $item_id,  $city ) );
	
	}
	
	function list_table_actions ( $page, $item, $page_number) {
		
		$item_id = (isset($item['id']) && ((int)$item['id'] > 0)) ? $item['id'] : 0;
		$country_id = (isset($item['country_id']) && ((int)$item['country_id'] > 0)) ? $item['country_id'] : 0;
		$city = (isset($item['city'])) ? $item['city'] : "";
				
		$links = array( 'city' => array('delete' => sprintf( "<a href=\"?page=%s&delete_id=%d&paged=%d&country_id=%d\" onclick=\" return confirm('Are yuu sure you want to delete " . $city . "?');\">Delete Permanently</a>", $page, $item_id, $page_number, $country_id ),
										'edit' => sprintf( '<a href="?page=%s&id=%d&country_id=%d">Edit</a>', 'saturn-tables-add-edit-city', $item_id, $country_id ) ) );
	
	
		return $links;
	}
	
	
	function process_link_actions() {
		
		global $wpdb;
		
		$country_id = isset($_GET['country_id']) ? (int)$_GET['country_id'] : 0;
			
		if ( (isset($_GET['delete_id']) &&  $delete_id = (int)$_GET['delete_id']) > 0) {		
			
			$wpdb->delete( 'saturn_tables_cities', array('id' => $delete_id),  array('%d'));
			
			//redirect without delete_id
			parse_str($_SERVER['QUERY_STRING'], $query_string);
			$query_string['country_id'] = $country_id;
			unset($query_string['delete_id']);
			$redirect = admin_url("admin.php") . "?" . http_build_query($query_string);
			wp_redirect( $redirect );		
			exit;
		}
		
	}

}

/********************************************/
/* END CITIES LIST TABLE CALLABLE FUNCTIONS */
/********************************************/

/************************************************/
/* CITIES INPUT FORM DEFINITION MENU CALLBACK */
/************************************************/

function saturn_tables_add_edit_city_func() {
	
	$form = new Saturn_Tables_Cities_Input_Form();
	
	$id = isset($_GET['country_id']) ? $_GET['country_id'] : 0;
	$input_form_definitions['menu_title'] = $id > 0 ? '<h1  class="wp-heading-inline">Edit City</h1> <strong>[Country ID:' . $id . ']</strong>' : '<h1>Add Country</h1>';
	$input_form_definitions['header'] = $id > 0 ? '<p>Edit citiy below with this form.</p>' : '<p>Input new city with this form.</p>';	
	$input_form_definitions['form_definition'] = array($form, 'input_form_definition');
	$input_form_definitions['run_query'] = array($form, 'run_query');
	$input_form_definitions['process_post_vars'] = array($form, 'process_post_vars');
	$input_form_definitions['footer'] = '<p>Powered by <a href="https://saturntables.com/" target="_blank">Saturn Tables</a></p>';	
	
	return $input_form_definitions;
}

/****************************************************/
/* END CITIES INPUT FORM DEFINITION MENU CALLBACK */
/****************************************************/


/*******************************************/
/* COUNTRIES INPUT FORM CALLABLE FUNCTIONS */
/*******************************************/

class Saturn_Tables_Cities_Input_Form {


	function input_form_definition() {
		
		global $wpdb;
		
		
		$input_form['action'] = array('type'=>"hidden", "value" => "postback" );
		$input_form['city'] = array ('label'=> "City", 'type' => "text", "required" => "");
		$input_form['country'] = array ('label'=> "Country", 'type' => "text", "required" => "", 'readonly' => "");
		$input_form['latitiude'] = array ('label'=> "Latitiude", 'type' => "number", 'step'=>".0001", "required" => "");
		$input_form['longitude'] = array ('label'=> "Longitude", 'type' => "number", 'step'=>".0001", "required" => "");
		$input_form['iso2'] = array('label'=> "iso2", 'type'=>"text", "required" => "", 'readonly' => "");
		$input_form['iso3'] = array( 'label'=> "iso3", 'type'=>"text",  "required" => "", 'readonly' => "");
		$input_form['state'] = array ('label'=> "State/Province", 'type' => "text");
		$input_form['capital'] = array ('label'=> "Capital", 'type' => "text");
		$input_form['population'] = array ('label'=> "Population", 'type' => "number", 'step'=>"1", "required" => "");
			
		return $input_form;
		
	}
	
	
	function run_query($input_form, $query_return) {
		
		 
		global $wpdb;
		
		if (isset($_POST['submit'])) {
		
			$country_id = isset($_GET['country_id']) ? (int)$_GET['country_id'] : 0;
		
			foreach ($input_form as $key => $value) {
				if (isset($_POST[$key]))
					$post_vars[$key] = sanitize_text_field($_POST[$key]);
			}

				
			if ($country_id > 0) {
			
				$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
				
				if (!$id && $country_id) {
					
					 $data = array('country_id' => $country_id, 'city' => $post_vars['city'], 'country' => $post_vars['country'], 'latitiude' => $post_vars['latitiude'], 'longitude' => $post_vars['longitude'],
								   'iso2' => $post_vars['iso2'], 'iso3' => $post_vars['iso3'], 'state' => $post_vars['state'], 'capital' => $post_vars['capital'], 'population' => $post_vars['population']);
					 $formats = array('%d','%s','%s','%f','%f','%s','%s','%s','%s','%d');
					 if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_cities'")) {
						$query_return = $wpdb->insert('saturn_tables_cities', $data, $formats);
						return false;
					 }
					 
					 
				} elseif ($country_id && $id) {
					
					$data = array('country_id' => $country_id, 'city' => $post_vars['city'], 'country' => $post_vars['country'], 'latitiude' => $post_vars['latitiude'], 'longitude' => $post_vars['longitude'],
								   'iso2' => $post_vars['iso2'], 'iso3' => $post_vars['iso3'], 'state' => $post_vars['state'], 'capital' => $post_vars['capital'], 'population' => $post_vars['population']);
					$data_formats =  array('%d','%s','%s','%f','%f','%s','%s','%s','%s','%d');
					$where = array('id' => $id);
					$where_formats = array('%d');
					if ($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_cities'")) {
						$query_return = $wpdb->update('saturn_tables_cities', $data, $where, $data_formats, $where_formats );			
						return false;
					}
				}
			}
		}	
	}
	
	
	function process_post_vars($input_form, $query_return, $post_vars) {
		
		global $wpdb;
		
		$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
		$country_id = (int)$_GET['country_id'];
		
		$post_vars = array();
		
		//input populate
		if ($country_id && !$id) {	
			if (count($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_countries'"))) {
				$post_vars = $wpdb->get_row( $wpdb->prepare("SELECT country, iso2, iso3 FROM saturn_tables_countries WHERE id = %d", $country_id) , ARRAY_A );
				return $post_vars;
			}
		//edit postback or populate
		} if ($id && $country_id && !$query_return) {
			if (count($wpdb->get_var("SHOW TABLES LIKE 'saturn_tables_cities'"))) {
				$post_vars = $wpdb->get_row($wpdb->prepare("SELECT city, latitiude, longitude, country, iso2, iso3, state, capital, population FROM saturn_tables_cities WHERE id = %d", $id), ARRAY_A);
				return $post_vars;
			}
		}
		return $post_vars;
	}
}

/***********************************************/
/* END COUNTRIES INPUT FORM CALLABLE FUNCTIONS */
/***********************************************/

function saturn_tables_cities_countries_import_func() {
	
	global $wpdb;
	
	if (isset($_POST['create_table']) && ($_POST['create_table'] == "Create Cities Data Table")) {
		
		if (is_uploaded_file($_FILES['cities_data']["tmp_name"])) {
			
			$query =    "DROP TABLE IF EXISTS `saturn_tables_cities`;";
			$wpdb->query($query);
			
			$query =    "CREATE TABLE `saturn_tables_cities` (
						`id` int(11) NOT NULL AUTO_INCREMENT,
						`country_id` int(11) NOT NULL,
						`city` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`latitiude` decimal(10,4) NOT NULL,
						`longitude` decimal(10,4) NOT NULL,
						`country` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`iso2` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`iso3` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`state` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`capital` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`population` bigint(20) NOT NULL,
						PRIMARY KEY (`id`)
					   ) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
";
			$table_created = $wpdb->query($query);
			
			$handle = fopen($_FILES['cities_data']["tmp_name"], "rb");
			
			if ($handle) {
				
				if (!feof($handle))
					$header = str_getcsv(fgets($handle));
				
				while (!feof($handle) ) {
				
					$line = fgets($handle);
					$arr = array_combine($header, str_getcsv($line));
					$result = $wpdb->insert('saturn_tables_cities', $arr);
				}
				
			}
			
			$message = "Table saturn_tables_cities has been created and populated.";
			fclose($handle);
					
		}
	}

	elseif (isset($_POST['create_table']) && ($_POST['create_table'] == "Create Countries Data Table")) {
	
		if (is_uploaded_file($_FILES['countries_data']["tmp_name"])) {
			
			$query = "DROP TABLE IF EXISTS `saturn_tables_countries`;";
			$wpdb->query($query);
			
			$query =    "CREATE TABLE `saturn_tables_countries` (
						`id` int(11) NOT NULL AUTO_INCREMENT,
						`iso2` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`iso3` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`country` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`region` text COLLATE utf8mb4_unicode_ci NOT NULL,
						`population` int(11) NOT NULL,
						`area` int(11) NOT NULL,
						`density` decimal(10,1) NOT NULL,
						`gdp` int(11) NOT NULL,
						`literacy` decimal(10,1) NOT NULL,
						PRIMARY KEY (`id`)
						) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci";
			$table_created = $wpdb->query($query);
			
			$handle = fopen($_FILES['countries_data']["tmp_name"], "rb");
			
			if ($handle) {
				
				if (!feof($handle))
					$header = str_getcsv(fgets($handle));
				
				while (!feof($handle) ) {
				
					$line = fgets($handle);
					$arr = array_combine($header, str_getcsv($line));
					$result = $wpdb->insert('saturn_tables_countries', $arr);
				}
				
			}
			
			fclose($handle);
			$message = "Table saturn_tables_countries has been created and populated.";	
		}
	}

		
	elseif (isset($_POST['delete_tables']) && ($_POST['delete_tables'] == "Delete Countries and Cities Data Tables")) {
		
			$query = "DROP TABLE IF EXISTS `saturn_tables_countries`;";
			$wpdb->query($query);
			
			$query = "DROP TABLE IF EXISTS `saturn_tables_cities`;";
			$wpdb->query($query);
			
			$message = "Table saturn_tables_countries and saturn_tables_countries have been dropped.";	
	}
	
?>

<div class="wrap">
	
<h1>Countries and Cities Dataset Function</h1>

<?php if (isset($message) and is_string($message)) echo '<div class="notice notice-success is-dismissible"><p>' . __( $message ) . '</p></div>'; ?>

<form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" enctype='multipart/form-data'>
<div style="padding: 20px 20px 30px; border: 1px solid #CCCCCC; margin: 10px 0; display: table-cell;">
<p>Load the Countries dataset (saturn_tables_countries_data.csv) and create the saturn_tables_countries data table.</p>
<input type="file" name="countries_data" />
<?php submit_button("Create Countries Data Table", "button", "create_table", false); ?>
</div><br>
<div style="padding: 20px 20px 30px; border: 1px solid #CCCCCC; margin: 10px 0; display: table-cell;">
<p>Load the Cities dataset (saturn_tables_cities_data.csv) and create the saturn_tables_cities data table.</p>
<input type="file" name="cities_data" />
<?php submit_button("Create Cities Data Table", "button", "create_table", false); ?>
</div><br>
<div style="padding: 20px 20px 30px; border: 1px solid #CCCCCC; margin: 10px 0; display: table-cell;">
<p>Delete the Countries and Cars tables when finished with the example.</p>
<?php submit_button("Delete Countries and Cities Data Tables", "button", "delete_tables", false); ?>
</div>
</form>

</div>
<?php
}


	
?>